<?php
/************************************************************************
 * MXChange v0.2.1                                    Start: 08/31/2008 *
 * ================                             Last change: 08/31/2008 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-list_surfbar_urls.php                       *
 * -------------------------------------------------------------------- *
 * Short description : List all URLs in surfbar and sync from mail pool *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Alle URLs in Surfbar auflisten und syncen        *
 * -------------------------------------------------------------------- *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2008 by Roland Haeder                           *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if ((!defined('__SECURITY')) || (!IS_ADMIN())) {
	$INC = substr(dirname(__FILE__), 0, strpos(dirname(__FILE__), "/inc") + 4) . "/security.php";
	require($INC);
} // END - if

// Add description as navigation point
ADD_DESCR("admin", __FILE__);

// By default show the list...
$show = true;

// Edit or delete button hit?
if (isset($_POST['edit'])) {
	// Show entries for editing
	ADMIN_EDIT_ENTRIES_CONFIRM(
		$_POST['id'],
		"surfbar_urls",
		array("id", "userid", "url", "reward", "costs"),
		array("bigintval", "ADD_MEMBER_SELECTION_BOX", "", "TRANSLATE_COMMA", "TRANSLATE_COMMA"),
		array("", array(false, true, true), "", "", "")
	);
	$show = false;
} elseif (isset($_POST['do_edit'])) {
	// Change data of entries
	ADMIN_EDIT_ENTRIES_CONFIRM(
		$_POST['id'],
		"surfbar_urls",
		array(),
		array(),
		array(),
		true
	);
} elseif (isset($_POST['delete'])) {
	// Show entries for deletion
	ADMIN_DELETE_ENTRIES_CONFIRM(
		$_POST['id'],
		"surfbar_urls",
		array("id", "userid", "url", "registered"),
		array("bigintval", "ADMIN_USER_PROFILE_LINK", "FRAMETESTER", ""),
		array("", "", "", "")
	);
	$show = false;
} elseif (isset($_POST['do_delete'])) {
	// Remove entries from database
	ADMIN_DELETE_ENTRIES_CONFIRM($_POST['id'], "surfbar_urls", array(), array(), array(), true);
} elseif (isset($_POST['lock'])) {
	// Un-/lock selected URLs. This does not work for pending URLs
	ADMIN_LOCK_ENTRIES_CONFIRM(
		$_POST['id'],
		"surfbar_urls",
		array("id", "userid", "url", "registered", "status"),
		array("bigintval", "ADMIN_USER_PROFILE_LINK", "FRAMETESTER", "", "SURFBAR_TRANSLATE_STATUS"),
		array("", "", "", "", "")
	);
	$show = false;
} elseif (isset($_POST['do_lock'])) {
	// Un-/lock selected URLs. This does not work for pending URLs
	ADMIN_LOCK_ENTRIES_CONFIRM(
		$_POST['id'],
		"surfbar_urls",
		array(),
		array(),
		array(),
		array("status" => array("ACTIVE" => "LOCKED", "LOCKED" => "ACTIVE")),
		true
	);
} elseif (isset($_POST['undelete'])) {
	// Undelete selected URLs. This does only work for deleted URLs... ;-)
	ADMIN_UNDELETE_ENTRIES_CONFIRM(
		$_POST['id'],
		"surfbar_urls",
		array("id", "userid", "url", "registered", "status"),
		array("bigintval", "ADMIN_USER_PROFILE_LINK", "FRAMETESTER", "", "SURFBAR_TRANSLATE_STATUS"),
		array("", "", "", "", "")
	);
	$show = false;
} elseif (isset($_POST['do_undelete'])) {
	// Undelete selected URLs. This does only work for deleted URLs... ;-)
	ADMIN_UNDELETE_ENTRIES_CONFIRM(
		$_POST['id'],
		"surfbar_urls",
		array(),
		array(),
		array(),
		array("status" => array("DELETED" => "ACTIVE")),
		true
	);
}

// Show entries?
if (!$show) return false;

// List all URLs
$result = SQL_QUERY("SELECT id, userid, url, views_total, status, UNIX_TIMESTAMP(registered) AS registered, UNIX_TIMESTAMP(last_locked) AS last_locked, lock_reason
FROM "._MYSQL_PREFIX."_surfbar_urls
ORDER BY id ASC", __FILE__, __LINE__);

// Do we have some URLs left?
if (SQL_NUMROWS($result) > 0) {
	// List all URLs
	$OUT = ""; $SW = 2;
	while ($content = SQL_FETCHARRAY($result)) {
		// "Translate"/add content
		$content['sw']          = $SW;
		$content['userid']      = ADMIN_USER_PROFILE_LINK($content['userid']);
		$content['url']         = FRAMETESTER($content['url']);
		$content['views_total'] = TRANSLATE_COMMA($content['views_total']);
		$content['status']      = SURFBAR_TRANSLATE_STATUS($content['status']);
		$content['registered']  = MAKE_DATETIME($content['registered'], 2);
		$content['last_locked'] = MAKE_DATETIME($content['last_locked'], 2);
		if (empty($content['lock_reason'])) $content['lock_reason'] = "---";

		// Load row template
		$OUT .= LOAD_TEMPLATE("admin_list_surfbar_urls_row", true, $content);

		// Switch color
		$SW = 3 - $SW;
	} // END - while

	// Load main template
	LOAD_TEMPLATE("admin_list_surfbar_urls", false, $OUT);
} else {
	// No URLs in surfbar
	LOAD_TEMPLATE("admin_settings_saved", false, ADMIN_SURFBAR_NO_URLS_FOUND);
}

// Free result
SQL_FREERESULT($result);

//
?>
